| pequod_preview | R Documentation |
Draws a strip of coloured rectangles with labels using base R graphics. Useful for seeing a palette before committing to it in an analysis.
pequod_preview(palette = "log", labels = TRUE)
palette |
Palette name. See [palette_pequod()]. |
labels |
If ‘TRUE' (default) writes each colour’s label above the rectangle. |
The palette, invisibly.
pequod_preview("log")
pequod_preview("crew")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.